pub fn sha256_array(bytes: &[u8]) -> [u8; 32]Expand description
Compute the SHA-256 hash of bytes and return it as a fixed [u8; 32],
avoiding the heap allocation done by sha256_bytes.
pub fn sha256_array(bytes: &[u8]) -> [u8; 32]Compute the SHA-256 hash of bytes and return it as a fixed [u8; 32],
avoiding the heap allocation done by sha256_bytes.